<?php
/** Northern Sami (sámegiella)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Gálaniitoluodda
 * @author Jeblad
 * @author Kaganer
 * @author Laila
 * @author Linnea
 * @author Skuolfi
 * @author Teak
 * @author The Evil IP address
 * @author Trondtr
 * @author לערי ריינהארט
 */

$linkTrail = '/^(:?[a-zàáâçčʒǯđðéèêëǧǥȟíìîïıǩŋñóòôõßšŧúùûýÿüžþæøåäö]+)(.*)$/sDu';

$messages = array(
# User preference toggles
'tog-underline'               => 'Liŋkkaid vuolláisárgun',
'tog-highlightbroken'         => 'Čájet liŋkkaid siidduide mat váilot <a href="#" class="new">ná</a> (molssaeaktun ná: <a href="#" class="internal">?</a>).',
'tog-hideminor'               => 'Čiega unna rievdadusaid varas rievdadusat -listtus',
'tog-extendwatchlist'         => 'Viiddit čuovvunlisttu, nu ahte čájeha buot dahkon rievdadusaid, iige dušše ođđaseamos',
'tog-usenewrc'                => 'Viiddiduvvon varas rievdadusat -listu (gáibida JavaScript)',
'tog-numberheadings'          => 'Nummaraste bajilčállagiid',
'tog-showtoolbar'             => 'Čájet rievdadangaskaomiid',
'tog-editondblclick'          => 'Rievdat siidduid duppaldeaddilemiin (JavaScript)',
'tog-editsection'             => 'Čájet rievdadanliŋkkaid juohke oasáža bajábealde',
'tog-editsectiononrightclick' => 'Rievdat osiid nu ahte deaddilat bajilčállaga sáhpána olgeš boaluin (JavaScript)',
'tog-showtoc'                 => 'Čájet sisdoallologahallama siidduin, main lea eanet go golbma bajilčállaga',
'tog-rememberpassword'        => 'Muite mu dieđuid dán dihtoris (for a maximum of $1 {{PLURAL:$1|day|days}})',
'tog-watchcreations'          => 'Lasit siidduid maid lean álggahan mu čuovvunlistui',
'tog-watchdefault'            => 'Lasit čuovvunlistui siidduid maid lean ođasmahttán',
'tog-watchmoves'              => 'Lasit čuovvunlistui siidduid maid lean sirdán',
'tog-watchdeletion'           => 'Lasit čuovvunlistui siidduid maid lean sihkkon',
'tog-minordefault'            => 'Rievdadusat leat unnit, jus ii eará álmmuhuvvo',
'tog-previewontop'            => 'Čájet siidduid rievdadusaid ovddalgihtii geahččama ođasmahttin lođá bajábealde',
'tog-previewonfirst'          => 'Čájehišgoađe siidduid rievdadusaid ovddalgihtii, go siiddu rievdadeapmi álggahuvvo',
'tog-nocache'                 => 'Ále vurke siidduid gaskaboddasašmuitui',
'tog-enotifwatchlistpages'    => 'Sádde dieđu e-poasttain go mu čuovvunlistui gullevaš siidu rievdaduvvo',
'tog-enotifusertalkpages'     => 'Sádde e-poasta, go geavaheaddjisiiddu ságastallansiidu rievdaduvvo',
'tog-enotifminoredits'        => 'Sádde dieđu e-poasttain maid unna rievdadusaid birra',
'tog-enotifrevealaddr'        => 'Čájet mu e-poastačujuhusa go sádden maila earáide',
'tog-shownumberswatching'     => 'Čájet galle geavaheaddji čuvvot siiddu',
'tog-fancysig'                => 'Oktageardán vuolláičálus liŋkka haga',
'tog-forceeditsummary'        => 'Fuomášuhte, jos in leat čállán čoahkkáigeasu',
'tog-watchlisthideown'        => 'Čiega mu iežan rievdadusaid',
'tog-watchlisthidebots'       => 'Čiega bot-prográmmaid rievdadusaid',
'tog-watchlisthideminor'      => 'Čiega unna rievdadusaid',
'tog-nolangconversion'        => 'Ále daga rievdadusaid giellavariánttaid gaskal',
'tog-ccmeonemails'            => 'Sádde munnje kopiija e-poasttain, maid sádden eará geavaheddjiide',

'underline-always' => 'Álo',
'underline-never'  => 'Ii goassige',

# Dates
'sunday'        => 'sotnabeaivi',
'monday'        => 'vuossárga',
'tuesday'       => 'maŋŋebárga',
'wednesday'     => 'gaskavahkku',
'thursday'      => 'duorastat',
'friday'        => 'bearjadat',
'saturday'      => 'lávvordat',
'sun'           => 'So',
'mon'           => 'vu',
'tue'           => 'Dis',
'wed'           => 'ga',
'thu'           => 'du',
'fri'           => 'be',
'sat'           => 'Lá',
'january'       => 'ođđajagimánnu',
'february'      => 'guovvamánnu',
'march'         => 'njukčamánnu',
'april'         => 'cuoŋománnu',
'may_long'      => 'miessemánnu',
'june'          => 'geassemánnu',
'july'          => 'suoidnemánnu',
'august'        => 'borgemánnu',
'september'     => 'čakčamánnu',
'october'       => 'golggotmánnu',
'november'      => 'skábmamánnu',
'december'      => 'juovlamánnu',
'january-gen'   => 'ođđajagimánu',
'february-gen'  => 'guovvamánu',
'march-gen'     => 'njukčamánu',
'april-gen'     => 'cuoŋománu',
'may-gen'       => 'miessemánu',
'june-gen'      => 'geassemánu',
'july-gen'      => 'suoidnemánu',
'august-gen'    => 'borgemánu',
'september-gen' => 'čakčamánu',
'october-gen'   => 'golggotmánu',
'november-gen'  => 'skábmamánu',
'december-gen'  => 'juovlamánu',
'jan'           => 'ođđj',
'feb'           => 'guov',
'mar'           => 'njuk',
'apr'           => 'cuoŋ',
'may'           => 'mies',
'jun'           => 'geas',
'jul'           => 'suoi',
'aug'           => 'borg',
'sep'           => 'čakč',
'oct'           => 'golg',
'nov'           => 'skáb',
'dec'           => 'juov',

# Categories related messages
'pagecategories'         => '{{PLURAL:$1|Luohkká|Luohkát}}',
'category_header'        => 'Siiddut, mat gullet luohkkái $1',
'subcategories'          => 'Vuolleluohkát',
'category-media-header'  => 'Fiillat luohkás ”$1”',
'category-empty'         => "''Dán kategoriijas eai leat siiddut eaige fiillat.''",
'listingcontinuesabbrev' => 'joatk.',

'about'         => 'Dieđut',
'article'       => 'Sisdoallusiidu',
'newwindow'     => '(leahkasa ođđa vindui)',
'cancel'        => 'Šluhtte',
'moredotdotdot' => 'Lasi...',
'mypage'        => 'Mu siidu',
'mytalk'        => 'Mu ságastallan',
'anontalk'      => 'Ságastallan IP-čujuhussii',
'navigation'    => 'Navigašuvdna',
'and'           => '&#32;ja',

# Cologne Blue skin
'qbfind'         => 'Oza',
'qbbrowse'       => 'Bláđe',
'qbedit'         => 'Rievdat',
'qbpageoptions'  => 'Siidoásahusat',
'qbpageinfo'     => 'Siiddu dieđut',
'qbmyoptions'    => 'Ásahusat',
'qbspecialpages' => 'Doaibmasiiddut',

# Vector skin
'vector-action-addsection' => 'Lasit fáttá',
'vector-action-delete'     => 'Sihko',
'vector-action-move'       => 'Sirdde',
'vector-action-protect'    => 'Suodjal',
'vector-action-undelete'   => 'Máhcat',
'vector-action-unprotect'  => 'Rievdat suodjaleami',
'vector-view-create'       => 'Álggat',
'vector-view-edit'         => 'Rievdat',
'vector-view-history'      => 'Geahča historjjá',
'vector-view-view'         => 'Loga',
'vector-view-viewsource'   => 'Geahča gáldokoda',

'errorpagetitle'    => 'Feaila',
'returnto'          => 'Máhcat siidui $1.',
'tagline'           => '{{SITENAME}}',
'help'              => 'Veahkki',
'search'            => 'Ohcan',
'searchbutton'      => 'Oza',
'go'                => 'Mana',
'searcharticle'     => 'Mana',
'history'           => 'Siiddu historjá',
'history_short'     => 'Historjá',
'updatedmarker'     => 'beaiváduvvon du ovddit fitnama maŋŋá',
'printableversion'  => 'Prentenveršuvdna',
'permalink'         => 'Bissovaš liŋka',
'print'             => 'Prente',
'edit'              => 'Rievdat',
'editthispage'      => 'Rievdat dán siiddu',
'delete'            => 'Sihko',
'deletethispage'    => 'Sihko dán siiddu',
'undelete_short'    => 'Máhcat {{PLURAL:$1|ovtta rievdadusa|$1 rievdadusa}}',
'protect'           => 'Suodjal',
'protect_change'    => 'rievdat',
'protectthispage'   => 'Suodjal dán siiddu',
'unprotect'         => 'Sihko suodjalusa',
'unprotectthispage' => 'Sihko dán siiddu suodjalusa',
'newpage'           => 'Ođđa siidu',
'talkpage'          => 'Ságastala dán siiddu birra',
'talkpagelinktext'  => 'Ságastallan',
'specialpage'       => 'Sierrasiidu',
'personaltools'     => 'Persovnnalaš bargoneavvu',
'postcomment'       => 'Ođđa sekšuvdna',
'articlepage'       => 'Geahča sisdoalu',
'talk'              => 'Ságastallan',
'views'             => 'Čájáhusat',
'toolbox'           => 'Neavvobumbá',
'userpage'          => 'Čájet geavaheaddjesiiddu',
'projectpage'       => 'Čájet prošeaktasiiddu',
'imagepage'         => 'Čájet fiilasiiddu',
'mediawikipage'     => 'Čájet diehtosiiddu',
'templatepage'      => 'Čájet mállevuođđosiiddu',
'viewhelppage'      => 'Čájet veahkkesiiddu',
'categorypage'      => 'Čájet kategoriijasiiddu',
'viewtalkpage'      => 'Čájet ságastallansiiddu',
'otherlanguages'    => 'Eará gielaide',
'redirectedfrom'    => 'Stivrejuvvon ođđasit siiddus $1',
'redirectpagesub'   => 'Ođđasit-stivrensiidu',
'lastmodifiedat'    => 'Siidu lea maŋimustá rievdaduvvon $1 diibmu $2.',
'viewcount'         => 'Dát siidu lea čájehuvvon {{PLURAL:$1|oktii|$1 geardde}}.',
'protectedpage'     => 'Suodjáluvvon siidu',
'jumpto'            => 'Njuike:',
'jumptonavigation'  => 'navigašuvdnii',
'jumptosearch'      => 'ohcamii',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => '{{SITENAME}} birra',
'aboutpage'            => 'Project:Dieđut',
'copyright'            => 'Sisdoalu sáhttá geavahit liseanssain $1.',
'currentevents'        => 'Áigeguovdil',
'currentevents-url'    => 'Project:Áigeguovdil',
'disclaimers'          => 'Friijavuohta vástideamis',
'disclaimerpage'       => 'Project:Friijavuohta vástideamis',
'edithelp'             => 'Rievdadanrávvagat',
'edithelppage'         => 'Help:Mo rievdadit siidduid',
'helppage'             => 'Help:Sisdoallu',
'mainpage'             => 'Váldosiidu',
'mainpage-description' => 'Váldosiidu',
'portal'               => 'Gáffestohpu',
'portal-url'           => 'Project:Gáffestohpu',
'privacypage'          => 'Project:Personsuodjalus',

'versionrequired'     => 'MediaWikis gáibiduvvo unnimustá veršuvdna $1',
'versionrequiredtext' => 'MediaWikis gáibiduvvo unnimustá veršuvdna $1 dán siiddu geavaheapmái. Geahča [[Special:Version|veršuvdna]]',

'retrievedfrom'           => 'Vižžojuvvon čujuhusas $1',
'youhavenewmessages'      => 'Dutnje leat $1 ($2).',
'newmessageslink'         => 'ođđa dieđut',
'newmessagesdifflink'     => 'maŋimus rievdadus',
'youhavenewmessagesmulti' => 'Dutnje lea ođđa dieđut siiddus $1',
'editsection'             => 'rievdat',
'editold'                 => 'rievdat',
'editlink'                => 'ođasmahte',
'editsectionhint'         => 'Rievdat oasi $1',
'toc'                     => 'Sisdoallu',
'showtoc'                 => 'čájet',
'hidetoc'                 => 'čiega',
'thisisdeleted'           => 'Čájet dahje máhcat $1.',
'viewdeleted'             => 'Čájet $1?',
'restorelink'             => '{{PLURAL:$1|okta sihkkojuvvon rievdadus|$1 sihkkojuvvon rievdadusa}}',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Siidu',
'nstab-user'      => 'Geavaheaddjisiidu',
'nstab-media'     => 'Media',
'nstab-special'   => 'Erenoamáš',
'nstab-project'   => 'Prošeaktasiidu',
'nstab-image'     => 'Fiila',
'nstab-mediawiki' => 'Dieđáhus',
'nstab-template'  => 'Mállevuođđu',
'nstab-help'      => 'Veahkki',
'nstab-category'  => 'Luohkká',

# Main script and global functions
'nosuchaction'      => 'Dovdameahttun dahkku',
'nosuchspecialpage' => 'Diekkár doaibmasiidu ii dihtto',
'nospecialpagetext' => 'Wikiprográmma ii dovdda diekkár doaibmasiiddu.',

# General errors
'error'                => 'Feaila',
'databaseerror'        => 'Diehtovuođđofeaila',
'readonly'             => 'Diehtuvuođđu lea giddejuvvon',
'internalerror'        => 'Siskkaldas feaila',
'internalerror_info'   => 'Siskkaldas feaila: $1',
'filecopyerror'        => 'Fiilla <b>$1</b> kopieren fiilan <b>$2</b> ii lihkosmuvvan.',
'filerenameerror'      => 'Fiilla <b>$1</b> ođđasitnammadeapmi namain <b>$2</b> ii lihkosmuvvan.',
'filedeleteerror'      => 'Fiilla <b>$1</b> sihkkun ii lihkosmuvvan.',
'directorycreateerror' => 'Logahallama ”$1” ráhkadeapmi ii lihkosmuvvan.',
'filenotfound'         => 'Fiila <b>$1</b> ii dihtton.',
'fileexistserror'      => 'Fiilii ”$1” čállin ii lihkosmuvvan: fiila lea anus.',
'formerror'            => 'Skovi dieđut eai dohkke.',
'badarticleerror'      => 'Doaimma ii leat vejolaš dahkat dán siiddus.',
'cannotdelete'         => 'Siiddu dahje fiilla sihkkon ii lihkosmuvvan. Muhtun eará lea sáhttán sihkkut dan.',
'badtitle'             => 'Fuones bajilčála',
'badtitletext'         => 'Siiddu bájilčállagis lei feaila, dahje dat lei guoros dahje boastut ráhkaduvvon wikiid- dahje gielaidgaskasaš liŋka.',
'perfcached'           => 'Dieđut leat gaskabottosašmuittus eaige sihkkarit vástit dálá hámi. A maximum of {{PLURAL:$1|one result is|$1 results are}} available in the cache.',
'perfcachedts'         => 'Čuovvovaš data lea buktojuvvon gaskabottosašmuittus ja dat lea maŋimusta beaiváduvvon $1. A maximum of {{PLURAL:$4|one result is|$4 results are}} available in the cache.',
'querypage-no-updates' => 'Dán siiddu dieđut eai beaiváduvvo.',
'viewsource'           => 'Geahča gáldu',
'protectedpagetext'    => 'Dát siidu lea suodjaluvvon rievdadusain.',
'viewsourcetext'       => 'Sáhtát geahčat ja kopieret dán siiddu gáldokoda:',
'sqlhidden'            => '(SQL-jearahallan lea čihkojuvvon)',

# Login and logout pages
'logouttext'                 => "'''Don leat dál loggen olggos {{GRAMMAR:elative|{{SITENAME}}}}s.'''

Sáhtát joatkit {{GRAMMAR:genitive|{{SITENAME}}}} geavaheami anonyman dahje logget ođđasit sisa",
'welcomecreation'            => '== Bures boahtin, $1! ==
Du geavaheaddjidovddaldat lea dál anus.
Ále vajáldahte rievdadit {{GRAMMAR:genitive|{{SITENAME}}}} iežat ásahusaid.',
'yourname'                   => 'Geavaheaddjidovddaldat',
'yourpassword'               => 'Suollemassátni:',
'yourpasswordagain'          => 'Čále suollemassáni ođđasit:',
'remembermypassword'         => 'Muite mu (for a maximum of $1 {{PLURAL:$1|day|days}})',
'yourdomainname'             => 'Fierbmenamma',
'login'                      => 'Čálligoađe sisa',
'nav-login-createaccount'    => 'Daga ođđa geavaheaddjidovddaldaga dahje čálligoađe sisa',
'loginprompt'                => 'Sisačállimii dárbbašuvvojit geavssat (cookies).',
'userlogin'                  => 'Logge sisa dahje ráhkat dovddaldaga',
'logout'                     => 'Čálligoađe olggos',
'userlogout'                 => 'Logge olggos',
'notloggedin'                => 'It leat čálligoahttan sisa',
'nologin'                    => "Jus dus ii vel leat geavaheaddjidovddaldat, sáhtát '''$1''' dakkára.",
'nologinlink'                => 'ráhkadit',
'createaccount'              => 'Ráhkat dovddaldaga',
'gotaccount'                 => "Jus dus lea jo geavaheaddjidovddaldat, sáhtát '''$1'''.",
'gotaccountlink'             => 'Logge sisa',
'createaccountmail'          => 'e-poasttain',
'badretype'                  => 'Suollemassánit maid čállet eai leat seammalaganat.',
'userexists'                 => 'Geavaheaddjidovddaldat, man evttohit, lea jo anus. Leage buorre ja vállje nubbi geavaheaddjidovddaldaga.',
'loginerror'                 => 'Feaila sisačálidettiin',
'nocookieslogin'             => '{{SITENAME}} geavaha diehtočoahkuid (cookies) sisačállima oktavuođas. Du neahttabláđejeaddji ii suova geavahit diehtočoahkuid. Váldde daid atnui ja iskka ođđasit.',
'noname'                     => 'It leat meroštallan buorre geavaheaddjidovddaldaga.',
'loginsuccesstitle'          => 'Sisačállin lihkosmuvai',
'loginsuccess'               => 'Leat čálligoahtan sisa geavaheaddjidovddaldagain $1.',
'nosuchuser'                 => 'Geavaheaddjidovddaldat ”$1” ii dihtto. Dárkis čálletgo dovddaldaga riekta dahke geavat skovi vuolábealde ja ráhkat ođđa geavaheaddjidovddaldaga.',
'nosuchusershort'            => 'Geavaheaddjidovddaldat ”$1” ii dihtto. Čálletgo dovddaldaga riekta?',
'nouserspecified'            => 'Geavaheaddjidovddaldat ii leat meroštallojuvvon.',
'wrongpassword'              => 'Suollemassátni, man čállet, ii leat riekta. Leage buorre ja iska ođđasit.',
'wrongpasswordempty'         => 'It čállán suollemassáni. Iska ođđasit.',
'passwordtooshort'           => 'Suollemassátni, man evttohit, ii heive. Suollemassátni ferte leat unnimustá $1 mearka guhkki ja eará go geavaheaddjidovddaldagat.',
'password-name-match'        => 'Suollemassátni ferte leat eará go geavaheaddjidovddaldat.',
'mailmypassword'             => 'Sádde ođđa suollemassáni e-poasta bokte',
'passwordremindertitle'      => 'Suollemassátnimuituhus {{GRAMMAR:elative|{{SITENAME}}}}',
'passwordremindertext'       => 'Muhtun IP-čujuhusas $1 bivddii {{GRAMMAR:partitive|{{SITENAME}}}} ($4) sáddet ođđa suollemassáni. Suollemassátni geavaheaddjái $2 lea dál $3. Čálligoađe sisa ja molsso suollemassáni.',
'noemail'                    => "Geavaheaddjái '''$1''' ii leat lasihuvvon e-poastačujuhus.",
'noemailcreate'              => 'Fertet čállit e-poastačujuhusa, mii lea geavahusas',
'passwordsent'               => 'Ođđa suollemassátni lea sáddejuvvon geavaheaddji <b>$1</b> e-poastačujuhussii.',
'throttled-mailpassword'     => 'Suollemassátnimuituhus lea sáddejuvvon maŋimus $1 diimma siste. Suollemassátnimuituhus sáddejuvvo eanemusta oktii $1 diimmas.',
'mailerror'                  => 'Feaila e-poastta sáddedettiin: $1',
'acct_creation_throttle_hit' => 'Leat jo ráhkadan $1 dovddaldaga. It sáhte ráhkadit ođđa.',
'emailauthenticated'         => 'E-poastačujuhusat lea sihkarastojuvvon $1.',
'emailnotauthenticated'      => 'E-poastačujuhusat ii leat vel sihkarastojuvvon. Vuolábeale doaimmaide laktaseaddji e-poasttat eai sáddejuvvo.',
'noemailprefs'               => 'E-poastačujuhus ii leat lasihuvvon.',
'emailconfirmlink'           => 'Sihkaraste e-postačujuhusa',
'invalidemailaddress'        => 'E-poastačujuhusa ii sáhte dohkehit, daningo dat ii leat rivttes hámis. Leage buorre ja adde rivttes e-poastačujuhusa dahje gurre dan.',
'accountcreated'             => 'Geavaheaddjidovddaldat lea ráhkaduvvon',
'accountcreatedtext'         => 'Geavaheaddji $1 geavaheaddjidovddaldat ráhkaduvvui.',
'loginlanguagelabel'         => 'Giella: $1',

# Change password dialog
'resetpass'                 => 'Suollemassáni gurren',
'resetpass_announce'        => 'Čálligohtet sisa e-poasttain sáddejuvvon suollemassánin. Fertet addit ođđa suollemassáni dasa:',
'resetpass_text'            => '<!-- Lasit dasa teavstta -->',
'resetpass_header'          => 'Ođđa suollemassáni čállin',
'oldpassword'               => 'Boares suollemassátni',
'newpassword'               => 'Ođđa suollemassátni',
'retypenew'                 => 'Ođđa suollemassátni ođđasit',
'resetpass_submit'          => 'Čále suollemassáni ja čálligoađe sisa',
'resetpass_success'         => 'Suollemassáni rievdadeapmim lihkosmuvai.',
'resetpass_forbidden'       => 'Suollemassániid rievdan ii lihkosmuva dán wikis.',
'resetpass-submit-loggedin' => 'Molsso suollemassáni',

# Edit page toolbar
'bold_sample'     => 'Buoiddes teaksta',
'bold_tip'        => 'Buoiddes teaksta',
'italic_sample'   => 'Vitnju teaksta',
'italic_tip'      => 'Vitnju teaksta',
'link_sample'     => 'liŋka',
'link_tip'        => 'Siskkaldas liŋka',
'extlink_sample'  => 'http://www.example.com liŋkka bájilčála',
'extlink_tip'     => 'Wiki olggobeal liŋka (muite http:// ovddas)',
'headline_sample' => 'Bájilčálateaksta',
'headline_tip'    => 'Bajilčála',
'nowiki_sample'   => 'Lasit rievdatkeahtes teavstta dasa',
'nowiki_tip'      => 'Teaksta, man wiki ii rievdda',
'image_sample'    => 'Ovdamearka.jpg',
'image_tip'       => 'Vurkejuvvon govva',
'media_sample'    => 'Ovdamearka.ogg',
'media_tip'       => 'Mediafiilaliŋka',
'sig_tip'         => 'Vuolláičálus áiggiin',
'hr_tip'          => 'Láskkosárggis',

# Edit pages
'summary'                        => 'Čoahkkáigeassu:',
'subject'                        => 'Fáddá:',
'minoredit'                      => 'Dát lea unna rievdadus',
'watchthis'                      => 'Lasit čuovvunlistui',
'savearticle'                    => 'Vurke siiddu',
'preview'                        => 'Siiddu ovdalgihtiigeahččan',
'showpreview'                    => 'Geahča ovdalgiihtii',
'showlivepreview'                => 'Ovdalgeahčastan',
'showdiff'                       => 'Čájet rievdadusaid',
'anoneditwarning'                => "'''Váruhus:''' It leat loggen sisa. Du IP-čujuhus báhcá dán siiddu rievdadushistorjái.",
'missingsummary'                 => 'It leat čállán čoahkkáigeasu. Jus válljet Vurke ođđasit, de rievdadusat maid ráhkadit vurkejuvvo čoahkkáigeasuhaga.',
'missingcommenttext'             => 'Čále čoahkkáigeasu vuollái.',
'missingcommentheader'           => 'It leat čállán bajilčállaga du oaivilii. Vállje <em>Vurke</em>, jus it hálit čállit bajilčállaga.',
'summary-preview'                => 'Čoahkkáigeasu ovdalgihtiigeahččan:',
'subject-preview'                => 'Bajilčállaga ovdalgihtiigeahččan:',
'blockedtitle'                   => 'Geavaheaddji lea hehttejuvvon',
'whitelistedittext'              => 'Don fertet $1, ovdalgo sáhtát rievdadit siidduid.',
'confirmedittext'                => 'It sáhte rievdadit siiddu ovdalgo leat sihkarastan iežat e-poastačujuhusa. Sáhtat sihkarastit [[Special:Preferences|ásahussiidduin]].',
'nosuchsectiontitle'             => 'Diekkár oassi ii gávdno',
'nosuchsectiontext'              => 'Isket rievdadit oasi, mii ii gávdno.',
'loginreqtitle'                  => 'Sisačállin gáibiduvvo',
'loginreqlink'                   => 'logge sisa',
'loginreqpagetext'               => 'Don fertet $1, ovdalgo oainnat eará siidduid.',
'accmailtitle'                   => 'Suollemassátni lea sáddejuvvon.',
'accmailtext'                    => "geavaheaddji '''$1''' suollemassátni lea sáddejuvvon čujuhussii '''$2'''.",
'newarticle'                     => '(ođđa)',
'newarticletext'                 => 'Leat boahtán muhtin liŋkka mielde siidui, mii ii vel lea čállejuvvon. Sáhtát álggahit siiddu vuollái. Jus it háliit álggahit siiddu, geavat fierbmilohkki máhccandoaimma.',
'userpage-userdoesnotexist'      => 'Geavaheaddjedovddaldat «$1» ii leat registrerejuvvon. Hálidatgo duođas rievdadit dán siiddu?',
'userpage-userdoesnotexist-view' => 'Geavaheaddjedovddaldat «$1» ii leat registrerejuvvon.',
'updated'                        => '(Beaiváduvvon)',
'note'                           => "'''Cuigehus:'''",
'previewnote'                    => "'''Dát lea siiddu ovdalgihtiigeahččan. Siidu ii leat vel vurkejuvvon!'''",
'editing'                        => 'Rievdadit siiddu $1',
'editingsection'                 => 'Rievdadit oasi siiddus $1',
'editingcomment'                 => 'Rievdadit kommeanta siiddus $1',
'explainconflict'                => "Soames lea rievdadan dán siiddu dan maŋŋel go don leat álgan rievdadit dan.
Bajit oasis oidno siiddu teaksta dálá hámis.
Du rievdadusat oidnojit vuolit oasis.
Don fertet dahkat du rievdadusaid dálá tekstii.
'''Beare''' bajit oasi teaksta vurkejuvvo go deaddilat «{{int:savearticle}}».",
'yourtext'                       => 'Iežat teaksta',
'storedversion'                  => 'Vurkejuvvon veršuvdna',
'yourdiff'                       => 'Erohusat',
'semiprotectedpagewarning'       => 'Beare registeren geavaheaddjit sáhtet rievdadit dán siiddu.',
'templatesused'                  => 'Mállevuođut mat geavahuvvojit dán siiddus:',
'templatesusedpreview'           => 'Mállevuođut mat leat mielde ovdagihtiigeahččamis:',
'templatesusedsection'           => 'Mállevuođut, mat leat dán oasis:',
'template-protected'             => '(suodjáluvvon)',
'template-semiprotected'         => '(suodjáluvvon anonyma ja ođđa geavaheddjiin)',
'edittools'                      => '<!-- Teaksta mii lea dás, čájehuvvo rievdadanskovi vuolábealde. -->',
'nocreatetitle'                  => 'Siidduid álggaheapmi lea ráddjejuvvon',

# Account creation failure
'cantcreateaccounttitle' => 'Dovddaldaga ráhkadeapmi ii lihkosmuvvan',

# History pages
'viewpagelogs'           => 'Čájet dán siiddu loggaid',
'nohistory'              => 'Dán siiddus ii leat rievdadanhistorjá.',
'currentrev'             => 'Dálá veršuvdna',
'revisionasof'           => 'Veršuvdna $1',
'revision-info'          => 'Dálá veršuvdna $1 – ráhkadan $2',
'previousrevision'       => '← Boarrásut veršuvdna',
'nextrevision'           => 'Ođđasut veršuvdna →',
'currentrevisionlink'    => 'Dálá veršuvdna',
'cur'                    => 'dálá',
'next'                   => 'čuovvovaš',
'last'                   => 'ovddit',
'page_first'             => 'vuosttas siidu',
'page_last'              => 'maŋimus siidu',
'history-fieldset-title' => 'Bláđe historjjá',
'histfirst'              => 'Vuosttas',
'histlast'               => 'Maŋimus',
'historysize'            => '($1 stávvala)',
'historyempty'           => '(guoros)',

# Revision feed
'history-feed-title'          => 'Rievdadushistorjá',
'history-feed-description'    => 'Dán siiddu rievdadushistorjá',
'history-feed-item-nocomment' => '$1 ($2)',

# Revision deletion
'rev-deleted-comment'       => '(kommentára lea sihkkojuvvon)',
'rev-deleted-user'          => '(geavaheaddjinamma lea sihkkojuvvon)',
'rev-deleted-event'         => '(dáhpáhus lea sihkojuvvon)',
'rev-delundel'              => 'čájet dahje čiega',
'revisiondelete'            => 'Sihko dahje máhcat veršuvnnaid',
'revdelete-nooldid-title'   => 'Ii veršuvdna',
'revdelete-selected'        => "'''{{PLURAL:$2|Válljejuvvon veršuvdna|Válljejuvvon veršuvnnat}} siiddus [[:$1]]'''",
'logdelete-selected'        => "'''{{PLURAL:$1|Válljejuvvon logmearkkastat|Válljejuvvon logmearkkastagat}}:'''",
'revdelete-text'            => "'''Sihkojuvvon veršuvnnat oidnojit siiddu siidohistorjjás, muhto daid sisdoallu ii leat álmmolaš.'''

Eará bajasdoallit sáhtet lohkat čihkojuvvon sisdoalu ja máhcahit dan.",
'revdelete-legend'          => 'Veršuvnna rádjehusat',
'revdelete-hide-text'       => 'Čiega veršuvnna sisdoalu',
'revdelete-hide-image'      => 'Čiega fiilla sisdoalu',
'revdelete-hide-name'       => 'Čiega doaibma ja mearri',
'revdelete-hide-comment'    => 'Čiega čoahkkáigeasu',
'revdelete-hide-user'       => 'Čiega dahkki dovddaldaga dahje IP-čujuhusa',
'revdelete-radio-set'       => 'Jua',
'revdelete-radio-unset'     => 'Ii',
'revdelete-suppress'        => 'Čiega maid bajasdolliin',
'revdelete-unsuppress'      => 'Sihko máhcahuvvon veršuvnnaid rádjehusaid',
'revdelete-log'             => 'Sivva',
'revdelete-submit'          => 'Daga',
'pagehist'                  => 'Siiddu rievdanhistorjá',
'deletedhist'               => 'Šluhtejuvvon veršuvnnaid historjá',
'revdelete-reason-dropdown' => '*Sivat
** Ii-almmolaš persovnnalaš dieđut
** Vejolaš gudnenrihkkun
** Vuovnnalaš geavaheaddjidovddaldat
** Vuovnnalaš sisdoallu',

# Diffs
'history-title'            => 'Siiddu «$1» historjá',
'difference'               => 'Veršuvnnaid erohusat',
'lineno'                   => 'Gurgadas $1:',
'compareselectedversions'  => 'Veardde válljejuvvon veršuvnnaid',
'showhideselectedversions' => 'Čájet/čiega válljejuvvon veršuvnnaid',
'editundo'                 => 'šluhtte',
'diff-multi'               => '(Veršuvnnaid gaskas {{PLURAL:$1|okta rievdadus|$1 eará rievdadusa}}.)',

# Search results
'searchresults'            => 'Ohcanbohtosat',
'searchresults-title'      => 'Ohcanbohtosat: «$1»',
'searchsubtitle'           => 'Ohcan tearpmain [[:$1]]',
'searchsubtitleinvalid'    => 'Ohcan tearpmain $1',
'notitlematches'           => 'Ohcansátni ii dihtton ovttasge bájilčállagis',
'prevn'                    => '← {{PLURAL:$1|$1}} ovddit',
'nextn'                    => '{{PLURAL:$1|$1}} čuovvovaš →',
'viewprevnext'             => 'Čájet [$3] oktanaga.

$1 {{int:pipe-separator}} $2',
'searchmenu-new'           => "'''Álggat siiddu ''[[:$1]]'' dán Wikipediai'''",
'searchhelp-url'           => 'Help:Rávvagat',
'searchprofile-articles'   => 'Sisdoallosiiddut',
'searchprofile-project'    => 'Veahkke- ja prošeaktasiiddut',
'searchprofile-everything' => 'Buot',
'searchprofile-advanced'   => 'Viiddiduvvon',
'showingresults'           => "{{PLURAL:$1|'''Okta''' boađus|'''$1''' bohtosa}} bohtosa'''$2''' rájes.",
'showingresultsnum'        => "Vuolábealde {{PLURAL:$3|lea '''okta''' ohcanboađus|leat '''$3''' ohcanbohtosa}} '''$2.''' bohtosa rájes.",
'powersearch'              => 'Oza',
'powersearch-ns'           => 'Oza nammagomuvuođain:',
'powersearch-redir'        => 'Listu ođđasitstivremiin',
'powersearch-togglelabel'  => 'Rievdat válljema:',
'powersearch-toggleall'    => 'Buot',
'powersearch-togglenone'   => 'Ii mihkkege',

# Quickbar
'qbsettings-none'          => 'Ii maidige',
'qbsettings-fixedleft'     => 'Teaksta mielde, gurut',
'qbsettings-fixedright'    => 'Teaksta mielde, olgeš',
'qbsettings-floatingleft'  => 'Biso gurutbealde',
'qbsettings-floatingright' => 'Biso olgesbealde',

# Preferences page
'preferences'           => 'Ásahusat',
'mypreferences'         => 'Ásahusat',
'prefs-edits'           => 'Rievdadusaid mearri:',
'prefsnologin'          => 'It leat čálligoahtán sisa',
'prefsnologintext'      => 'Don fertet [[Special:UserLogin|čálligoahtit sisa]], ovdalgo sáhtát rievdadit du ásahusaid.',
'changepassword'        => 'Suollemassáni molson',
'prefs-skin'            => 'Olggosoaidnu',
'skin-preview'          => 'ovdalgihtii geahččan...',
'datedefault'           => 'Eai válljemat',
'prefs-datetime'        => 'Áigi ja beaivemearri',
'prefs-personal'        => 'Geavaheaddjidieđut',
'prefs-rc'              => 'Varas rievdadusat',
'prefs-watchlist'       => 'Čuovvunlistu',
'prefs-watchlist-edits' => 'Rievdadusaid mearri čuovvunlisttus',
'prefs-misc'            => 'Eará',
'saveprefs'             => 'Vurke ásahusaid',
'resetprefs'            => 'Máhcat vurkejuvvon ásahusaid',
'prefs-editing'         => 'Rievdadeapmi',
'rows'                  => 'Gurgadasa:',
'columns'               => 'Kolumnat',
'searchresultshead'     => 'Ohcan',
'resultsperpage'        => 'Bohtosa juohke siiddus',
'recentchangescount'    => 'Siiddui mearri varas rievdadusain',
'savedprefs'            => 'Du ásahusid vurken lihkosmuvai.',
'timezonelegend'        => 'Áigeavádat',
'localtime'             => 'Báikálaš áigi',
'timezoneoffset'        => 'Áigeearru',
'servertime'            => 'Servera áigi',
'guesstimezone'         => 'Jeara neahttabláđejeaddjis',
'timezoneregion-africa' => 'Afrihkká',
'allowemail'            => 'Suova e-postta sádden čujuhussii',
'prefs-files'           => 'Fiillat',
'youremail'             => 'E-poastačujuhus',
'username'              => 'Geavaheaddjenamma:',
'uid'                   => 'Geavaheaddji-ID:',
'prefs-memberingroups'  => 'Miellahttu/lahttu {{PLURAL:$1|joavkkus|joavkkuin}}:',
'prefs-registration'    => 'Registrerenáigi:',
'yourrealname'          => 'Rivttes namma',
'yourlanguage'          => 'Geavahanvuođu giella',
'yourvariant'           => 'Giellavarianta:',
'yournick'              => 'Vuolláičálus',
'badsig'                => 'Vuolláičálus ii dohke.',
'badsiglength'          => 'Vuolláičálus lea menddo guhki - vuolláičálus sáhttá leat eanemusta $1 mearka.',
'yourgender'            => 'Sohkabealli:',
'gender-unknown'        => 'Ii diehtu',
'gender-male'           => 'Dievdu',
'gender-female'         => 'Nisson',
'email'                 => 'E-poastadoaimmat',
'prefs-help-realname'   => 'Eaktodahtolaš. Du namma čájehuvvo geavaheaddjidovddaldaga sajis siiddu dahkkilogahallamis.',
'prefs-help-email'      => 'Eaktodahtolaš. Eará geavaheaddjit sáhttet váldit dunnje oktavuođa e-poasttain nu ahte du e-poastačujuhus ii dihtto.',
'prefs-signature'       => 'Vuolláičálus',
'prefs-dateformat'      => 'Beaivemeari hábmi',

# User rights
'userrights'                   => 'Geavaheaddjevuoigatvuođaid stivren',
'userrights-lookup-user'       => 'Geavaheaddjirivttiid stivren',
'userrights-user-editname'     => 'Geavaheaddjidovddaldat',
'editusergroup'                => 'Rievdat geavaheaddjijoavkkuid',
'editinguser'                  => "Rievdadit siiddu '''[[User:$1|$1]]''' ([[User talk:$1|{{int:talkpagelinktext}}]] | [[Special:Contributions/$1|{{int:contribslink}}]])",
'userrights-editusergroup'     => 'Rievdat geavaheaddjejoavkku',
'saveusergroups'               => 'Vurke',
'userrights-groupsmember'      => 'Lahttun čuovvovaš joavkkuin:',
'userrights-groupsmember-auto' => 'Implikáhtalaš (miel)lahttu {{PLURAL:$1|joavkkus|joavkkuin}}:',
'userrights-reason'            => 'Sivva',
'userrights-changeable-col'    => 'Joavkkut, maid dus lea lohpi rievdadit',
'userrights-unchangeable-col'  => 'Joavkkut, maid dus ii leat lohpi rievdadit',

# Groups
'group'            => 'Joavku:',
'group-user'       => 'geavaheaddjit',
'group-bot'        => 'Bohtat',
'group-sysop'      => 'Administráhtorat',
'group-bureaucrat' => 'Byrokráhtat',
'group-all'        => '(buot)',

'group-bot-member'        => 'bohtta',
'group-sysop-member'      => 'administráhtorat',
'group-bureaucrat-member' => 'byrokráhtta',

'grouppage-bot'        => '{{ns:project}}:Bohtat',
'grouppage-sysop'      => '{{ns:project}}:Administráhtorat',
'grouppage-bureaucrat' => '{{ns:project}}:Byrokráhtat',

# User rights log
'rightslog'      => 'Logga geavaheaddjirievttiin',
'rightslogtext'  => 'Vuolábealde lea logga geavaheaddjirivttiid rievdadusain.',
'rightslogentry' => 'Geavaheaddji $1 rievttit rievdaduvvoi joavkkuin $2 joavkkuide $3',
'rightsnone'     => '(eai rievttit)',

# Associated actions - in the sentence "You do not have permission to X"
'action-createpage'    => 'álggahit siidduid',
'action-createtalk'    => 'álggahit ságastallansiidduid',
'action-browsearchive' => 'ohcat sihkkojuvvon siidduid',
'action-sendemail'     => 'sáddet e-poasttaid',

# Recent changes
'nchanges'                          => '$1 {{PLURAL:$1|rievdadus|rievdadusa}}',
'recentchanges'                     => 'Varas rievdadusat',
'recentchangestext'                 => 'Dán siiddus sáhtat čuovvut varas rievdadusaid {{GRAMMAR:illative|{{SITENAME}}}}.',
'recentchanges-feed-description'    => 'Dán siiddus sáhtat čuovvut varas {{GRAMMAR:illative|{{SITENAME}}}} rievdadusaid.',
'rcnote'                            => 'Vuollin {{PLURAL:$1|lea okta rievdadus|leat $1 varas rievdadusa}} {{PLURAL:$2|ovtta beaivvi|$2 maŋimus jándora}} áigge gitta $3 rádjái.',
'rcnotefrom'                        => "Vuolábealde leat rievdadusat '''$2''' rájes. Eanemusta '''$1''' mearkkastaga čájehuvvo.",
'rclistfrom'                        => 'Čájet ođđa rievdadusat $1 rájes',
'rcshowhideminor'                   => '$1 unna rievdádusat',
'rcshowhidebots'                    => '$1 bohtat',
'rcshowhideliu'                     => '$1 čálligoahtán geavaheaddjit',
'rcshowhideanons'                   => '$1 anonyma geavaheaddjit',
'rcshowhidepatr'                    => '$1 dárkistuvvon rievdadusat',
'rcshowhidemine'                    => '$1 iežas rievdádusat',
'rclinks'                           => 'Čájet $1 varas rievdadusa maŋimus $2 beaivve siste.<br />$3',
'diff'                              => 'erohus',
'hist'                              => 'hist',
'hide'                              => 'čiega',
'show'                              => 'čájet',
'minoreditletter'                   => 'u',
'newpageletter'                     => 'O',
'number_of_watching_users_pageview' => '[$1 čuovvujeaddji geavaheaddji]',
'rc_categories'                     => 'Beare luohkáin (earuheaddji lea ”|”)',
'rc_categories_any'                 => 'Mii beare',

# Recent changes linked
'recentchangeslinked'         => 'Dán siiddu varas rievdadusat',
'recentchangeslinked-feed'    => 'Dán siiddu varas rievdadusat',
'recentchangeslinked-toolbox' => 'Dán siiddu varas rievdadusat',
'recentchangeslinked-title'   => '"$1" laktaseaddji rievdadusat',

# Upload
'upload'              => 'Lasit fiilla',
'uploadbtn'           => 'Lasit fiilla',
'reuploaddesc'        => 'Máhca sáddenskovvái.',
'uploadnologin'       => 'It leat loggen sisa',
'uploadnologintext'   => 'Don fertet leat [[Special:UserLogin|čálligoahtán sisa]], ovdalgo sáhtát vurket fiillaid.',
'uploaderror'         => 'Vurkenfeaila',
'uploadlog'           => 'Fiilalogga',
'uploadlogpage'       => 'Fiilalogga',
'filename'            => 'Fiilla namma',
'filedesc'            => 'Čoahkkáigeassu',
'fileuploadsummary'   => 'Čoahkkáigeassu:',
'filesource'          => 'Gáldu:',
'uploadedfiles'       => 'Lasihuvvon fiillat',
'ignorewarning'       => 'Vurke fuolatkeahttá varuhusas',
'minlength1'          => 'Fiilla namas ferte leat unnimustá okta mearka.',
'badfilename'         => 'Fiila namma lea rievdaduvvon. Ođđa namma lea "$1".',
'filetype-missing'    => 'Fiillas vailui fiilageažus – ovdamearkkan <tt>.jpg</tt>.',
'large-file'          => 'Fiilla max. sturrodat lea $1. Fiila man lasihit lea $2.',
'largefileserver'     => 'Dát fiila lea menddo stuoris.',
'uploadwarning'       => 'Lasihanvaruhus',
'savefile'            => 'Vurke',
'uploadedimage'       => 'vurkii fiilla [[$1]]',
'overwroteimage'      => 'vurkii ođđa veršuvnna fiillas «[[$1]]»',
'uploaddisabled'      => '{{GRAMMAR:genitive|{{SITENAME}}}} ii sáhte lasihit fiillaid.',
'uploaddisabledtext'  => 'Fiillaid vurken lea váldojuvvon eret anus.',
'uploadscripted'      => 'Dát fiila sisdisdoalla HTML-koda dahje skriptaid, maid neahttabláđejeaddji sáhttá vahagis dahkat.',
'uploadvirus'         => 'Fiila sisdoalla virusa. Dárkilut dieđut: $1',
'sourcefilename'      => 'Gáldonamma',
'destfilename'        => 'Mearrenamma',
'watchthisupload'     => 'Čuovo dán siiddu',
'filewasdeleted'      => 'Dán nammasaš fiila lea lasihuvvon ja sihkojuvvon jo ovda. Dárkis $1 ovdalgo joatkat.',
'upload-success-subj' => 'Lasiheapmi lihkosmuvai',

'upload-proto-error' => 'Feaila protokollas',
'upload-file-error'  => 'Stuorra feaila',
'upload-misc-error'  => 'Feaila',

# Some likely curl errors. More could be added from <http://curl.haxx.se/libcurl/c/libcurl-errors.html>
'upload-curl-error6' => 'Čujuhus ii doaimma',

'license'            => 'Liseansa',
'license-header'     => 'Liseansa',
'nolicense'          => 'Ii liseansa',
'license-nopreview'  => '(ovdalgihtii geahččan ii leat vejolaš)',
'upload_source_url'  => ' (almmolaš URL-čujuhus)',
'upload_source_file' => ' (fiila dihtoris)',

# Special:ListFiles
'listfiles_search_for'  => 'Nammaohcan',
'imgfile'               => 'fiila',
'listfiles'             => 'Fiilalogahallan',
'listfiles_date'        => 'Beaivemearri',
'listfiles_name'        => 'Namma',
'listfiles_user'        => 'Vurkejeaddji',
'listfiles_size'        => 'Sturrodat',
'listfiles_description' => 'Govvádus',

# File description page
'file-anchor-link'          => 'Fiila',
'filehist'                  => 'Fiilla historjá',
'filehist-help'             => 'Go deaddilat beaivemeari, oainnat makká fiila lei dalle.',
'filehist-deleteall'        => 'sihko buot',
'filehist-deleteone'        => 'sihko dán',
'filehist-revert'           => 'ovddit veršuvdnii',
'filehist-current'          => 'dálá',
'filehist-datetime'         => 'Beaivemearri/Áigi',
'filehist-user'             => 'Geavaheaddji',
'filehist-dimensions'       => 'Sturrodat',
'filehist-filesize'         => 'Fiilasturrodat',
'filehist-comment'          => 'Kommeanta',
'imagelinks'                => 'Čujuheamit siidduin',
'linkstoimage'              => 'Čuovvovaš siidduin čujuhuvvo dán fiilii:',
'nolinkstoimage'            => 'Dán fiilii ii čujuhuvo ovttage siiddus.',
'sharedupload'              => 'Dát fiila lea juhkojuvvon ja eará prošeavttat sáhtet geavahit dan.',
'uploadnewversion-linktext' => 'Vurke ođđa veršuvnna dán fiillas',

# File reversion
'filerevert'                => 'Fiilla $1 máhcaheapmi',
'filerevert-legend'         => 'Fiilla máhcaheapmi',
'filerevert-intro'          => "Leat máhcaheami fiilla '''[[Media:$1|$1]]''' [$4 veršuvdnii, mii ráhkaduvvui $2 diibmu $3].",
'filerevert-comment'        => 'Sivva',
'filerevert-defaultcomment' => 'Máhcahuvvui veršuvdnii, mii ráhkaduvvui $1 diibmu $2',
'filerevert-submit'         => 'Ovddit veršuvdnii',
'filerevert-success'        => "'''[[Media:$1|$1]]''' lea máhcahuvvon [$4 veršuvdnii, mii ráhkaduvvui $2 diibmu $3].",
'filerevert-badversion'     => 'Fiillas ii leat ráhkaduvvon veršuvdna dalle.',

# File deletion
'filedelete'           => 'Sihko $1',
'filedelete-legend'    => 'Sihko fiilla',
'filedelete-intro'     => "Don leat sihkomin fiilla '''[[Media:$1|$1]]''' ja fiilla historjjá",
'filedelete-intro-old' => "Don leat sihkomin veršuvdna '''[[Media:$1|$1]]'''  [$4 $3, $2].",
'filedelete-comment'   => 'Sivva',
'filedelete-submit'    => 'Sihko',
'filedelete-success'   => "'''$1''' lea sihkojuvvon.",
'filedelete-nofile'    => "'''$1''' ii dihtto dán siiddus.",

# MIME search
'mimesearch' => 'MIME-ohcan',
'mimetype'   => 'MIME-tiipa',
'download'   => 'láde',

# Unwatched pages
'unwatchedpages' => 'Čuovvotkeahtes siiddut',

# List redirects
'listredirects' => 'Listu ođđasitstivremiin',

# Unused templates
'unusedtemplates'     => 'Geavatkeahtes mállevuođut',
'unusedtemplatestext' => 'Dás lea listu mállevuođuin, mat eai leat geavahuvvon ovttage siiddus. Muite dárkistit leago mállevuođđu das fuolatkeahttá anus.',
'unusedtemplateswlh'  => 'eará liŋkkat',

# Random page
'randompage'         => 'Summal siidu',
'randompage-nopages' => 'Dán nammagomuvuođas eai leat siiddut.',

# Random redirect
'randomredirect'         => 'Summal ođđasitstivren',
'randomredirect-nopages' => 'Dán nammagomuvuođas eai leat ođđasitstivremat.',

# Statistics
'statistics'                   => 'Statistihkat',
'statistics-header-users'      => 'Geavaheaddjistatistihkat',
'statistics-articles'          => 'Sisdoallosiiddut',
'statistics-pages'             => 'Siiddut',
'statistics-pages-desc'        => 'Buot siiddut dán wikis (ságastallansiiddut, prošeaktasiiddut, ođđasitstivremat, jed.)',
'statistics-files'             => 'Fiillat',
'statistics-edits'             => 'Rievdadusat maŋŋel dan go {{SITENAME}} vuođđuduvvui',
'statistics-edits-average'     => 'Gaskamearálaš rievdadusaid mearri/siidu',
'statistics-users'             => 'Registrerejuvvon [[Special:ListUsers|geavaheaddjit]]',
'statistics-users-active'      => 'Aktiivvalaš geavaheaddjit',
'statistics-users-active-desc' => 'Geavaheaddjit, geat leat bargan juoidá maŋimus {{PLURAL:$1|beaivvi|$1 beaivvi}} áigge.',
'statistics-mostpopular'       => 'Eanemusta gehčojuvvon siiddut',

'disambiguations' => 'Liŋkkat dárkonsiidduide',

'doubleredirects' => 'Guovttegeardán ođđasitstivremat',

'brokenredirects'        => 'Bieđganan ođđasitstivremat',
'brokenredirectstext'    => 'Čuovvovaš ođđasitstivremat leat artihkkaliidda, mat eai dihtto.',
'brokenredirects-edit'   => 'rievdat',
'brokenredirects-delete' => 'sihko',

'withoutinterwiki'         => 'Siiddut, main eai leat giellaliŋkkat',
'withoutinterwiki-summary' => 'Čuovvovaš siiddut eai čujut eará gielat veršuvnnaidda:',

'fewestrevisions' => 'Siiddut, mat leat rievdáduvvon hárvet',

# Miscellaneous special pages
'nbytes'                  => '$1 {{PLURAL:$1|stávval|stávvala}}',
'ncategories'             => '$1 {{PLURAL:$1|luohkká|luohká}}',
'nlinks'                  => '$1 {{PLURAL:$1|liŋka|liŋkka}}',
'nmembers'                => '$1 {{PLURAL:$1|lahttu|lahtu}}',
'nrevisions'              => '$1 {{PLURAL:$1|rievdádus|rievdádusa}}',
'nviews'                  => '$1 {{PLURAL:$1|láden|ládema}}',
'specialpage-empty'       => 'Dán siiddus ii leat teaksta.',
'lonelypages'             => 'Oarbbes siiddut',
'lonelypagestext'         => 'Čuovvovaš siidduide ii čujuhuvvo eará siidduin.',
'uncategorizedpages'      => 'Siiddut mat eai gula ovttage luohkkái',
'uncategorizedcategories' => 'Luohkát mat eai gula ovttage luohkkái',
'uncategorizedimages'     => 'Fiillat mat eai gula ovttage luohkkái',
'uncategorizedtemplates'  => 'Mállevuođut mat eai gula ovttage luohkkái',
'unusedcategories'        => 'Geavatkeahtes luohkát',
'unusedimages'            => 'Geavatkeahtes fiillat',
'popularpages'            => 'Bivnnuhis siiddut',
'wantedcategories'        => 'Luohkkásávaldagat',
'wantedpages'             => 'Siidusávaldagat',
'mostlinked'              => 'Siiddut maidda čujuhuvvo dávjjimustá',
'mostlinkedcategories'    => 'Luohkát, maidda čujuhuvvo dávjjimustá',
'mostlinkedtemplates'     => 'Mállevuođut, maidda čujuhuvvo dávjjimustá',
'mostcategories'          => 'Siiddut, mat gullet eanemus luohkáide',
'mostimages'              => 'Govat, maidda lea čujuhuvvon dávjjimus',
'mostrevisions'           => 'Siiddut, mat leat rievdáduvvon eanemustá',
'shortpages'              => 'Oanehis siiddut',
'longpages'               => 'Guhkes siiddut',
'deadendpages'            => 'Siiddut, main eai leat liŋkkat',
'deadendpagestext'        => 'Čuovvovaš siidduin eai leat liŋkkat eara siidduide dán wikis.',
'protectedpages'          => 'Suodjáluvvon siiddut',
'protectedpages-indef'    => 'Beare siiddut, maid suodjaleapmi lea bissovaš',
'protectedpages-cascade'  => 'Beare siiddut, maid suodjaleapmi lea viiddiduvvon',
'protectedpagestext'      => 'Čuovvovaš siiddut leat suodjáluvvon sirdimiin ja rievdadusain',
'protectedtitles'         => 'Suodjaluvvon siidonamat',
'listusers'               => 'Geavaheaddjilistu',
'newpages'                => 'Ođđa siiddut',
'newpages-username'       => 'Geavaheaddjidovddaldat:',
'ancientpages'            => 'Siiddut, mat eai leat rievdaduvvon guhkes áigái',
'move'                    => 'Sirdde',
'movethispage'            => 'Sirdde dán siiddu',
'unusedimagestext'        => 'Fuomaš, ahte eará neahttasiiddut sáhtet čujuhit fiilii njuolgga URL-čujuhusain. Dalle fiila soaitá leat dán listtus, vaikko dat leage anus.',
'unusedcategoriestext'    => 'Dát luohkát dihttot, muhto dat eai geavahuvvo.',
'notargettitle'           => 'Ii mearri',
'notargettext'            => 'It leat meroštallan mearresiiddu dahje -geavaheaddji, masa dahku laktása.',

# Book sources
'booksources'               => 'Girjegáldut',
'booksources-search-legend' => 'Oza girjegálduid',
'booksources-go'            => 'Oza',
'booksources-text'          => 'Vuolábealde leat liŋkkat olggobeal siidduide, main vuvdojuvvot ođđa ja boares girjjid. Siiddui sáhttá maid leat lassedieđut girjjiin.',

# Special:Log
'specialloguserlabel'  => 'Geavaheaddji:',
'speciallogtitlelabel' => 'Mearri',
'log'                  => 'Loggat',
'all-logs-page'        => 'Buot loggat',
'logempty'             => 'Eai dáhpáhusat loggas.',
'log-title-wildcard'   => 'Mearri álgá mearkkaiguin',

# Special:AllPages
'allpages'          => 'Buot siiddut',
'alphaindexline'    => '$1…$2',
'nextpage'          => 'Čuovvovaš siidu ($1)',
'prevpage'          => 'Ovddit siidu ($1)',
'allarticles'       => 'Buot siiddut',
'allinnamespace'    => 'Buot siiddut nammagomuvuođas $1',
'allnotinnamespace' => 'Buot siiddut, mat eai gula nammagomuvuhtii $1',
'allpagesprev'      => 'Ovddit',
'allpagesnext'      => 'Čuovvovaš',
'allpagessubmit'    => 'Oza',
'allpagesbadtitle'  => 'Čállojuvvon bájilčála lei dohkemeahtun dahje das lei wikiid gaskasaš álgooassi.',
'allpages-bad-ns'   => '{{GRAMMAR:inessive|{{SITENAME}}}} ii leat nammagomuvuohta ”$1”.',

# Special:Categories
'categories'         => 'Luohkát',
'categoriespagetext' => '{{GRAMMAR:inessive|{{SITENAME}}}} lea čuovvovaš luohkát.
[[Special:UnusedCategories|Unused categories]] are not shown here.
Also see [[Special:WantedCategories|wanted categories]].',

# Special:LinkSearch
'linksearch-ok' => 'Oza',

# Special:ListUsers
'listusers-submit'   => 'Oza',
'listusers-noresult' => 'Geavaheaddjit eai dihtton. Dárkis maid sierra bustávasturrodagat.',

# Special:ActiveUsers
'activeusers'            => 'Listu aktiivvalaš geavaheddjiin',
'activeusers-intro'      => 'Dát lea listu geavaheddjiin, mat leat bargan juoidá maŋimus $1 {{PLURAL:$1|beaivvi|beaivvi}} siste.',
'activeusers-count'      => '$1 {{PLURAL:$1|rievdadus|rievdadusa}} maŋimus $3 beaivvi siste',
'activeusers-from'       => 'Čájet geavaheddjiid dán rájes:',
'activeusers-hidebots'   => 'Čiega bohtaid',
'activeusers-hidesysops' => 'Čiega administráhtoriid',

# Special:ListGroupRights
'listgrouprights-members' => '(listu miellahtuin)',

# Email user
'mailnologin'     => 'Sáddejeaddji čujuhus váilo',
'mailnologintext' => 'Don fertet leat [[Special:UserLogin|čálligoahtán sisa]] ja du [[Special:Preferences|ásahusain]] ferte leat gelbbolaš ja <strong>sihkarastojuvvon</strong> e-poastačujuhus, ovdalgo sáhtat sáddet e-poasta eará geavaheddjiide.',
'emailuser'       => 'Čále e-poastta geavaheaddjái',
'emailpage'       => 'Sádde e-poastta geavaheaddjái',
'emailpagetext'   => 'Jus dát geavaheaddji lea lasihin iežaset ásahusaide gelbbolaš e-poastačujuhusa, vuolábeale skoviin sáhtat sáddet sudnje ovtta sáni. Iežat ásahusaide lasihuvvon e-poastačujuhus oidno sáddejeaddji dieđuin, vai vuostáiváldi sáhttá vástidit.',
'usermailererror' => 'Feaila e-poastta sáddedettiin:',
'defemailsubject' => '{{SITENAME}}-e-poasta',
'noemailtitle'    => 'Ii e-poastačujuhus',
'noemailtext'     => 'Dát geavaheaddji ii leat meroštallan e-poastačujuhusa dahje ii hálit e-poastta eará geavaheddjiin.',
'emailfrom'       => 'Sáddejeaddji',
'emailto'         => 'Vuostáiváldi',
'emailsubject'    => 'Fáddá',
'emailmessage'    => 'Sátni',
'emailsend'       => 'Sádde',
'emailccme'       => 'Sádde sánis kopiija mu e-poastačujuhussii.',
'emailccsubject'  => 'Kopiija sáddejuvvon sánis čujuhussii $1: $2',
'emailsent'       => 'E-poastasátni lea sáddejuvvon',
'emailsenttext'   => 'E-poastasátni lea sáddejuvvon.',
'emailuserfooter' => 'Dán e-poastta sáddii geavaheaddji $1 geavaheaddjái $2 {{SITENAME}} "E-mailUser"-doaimmain.',

# Watchlist
'watchlist'            => 'Čuovvunlistu',
'mywatchlist'          => 'Čuovvunlistu',
'nowatchlist'          => 'Du čuovvunlisttus eai leat siiddut.',
'watchlistanontext'    => 'Don fertet $1, jus hálidat geavahit čuovvunlisttu.',
'watchnologin'         => 'It leat čálligoahtán sisa',
'watchnologintext'     => 'Don fertet [[Special:UserLogin|čálligoahtit sisa]], jus hálidat geavahit du čuovvunlisttu.',
'addedwatchtext'       => "Siidu '''<nowiki>$1</nowiki>''' lea lasihuvvon [[Special:Watchlist|čuovvunlisttui]]. Boahtevuođas siiddu ja siiddu ságastallansiiddu rievdadusat almmuhuvvo dáppe. Siidu lea '''buidon''' [[Special:RecentChanges|varas rievdadusat -listtus]], vai fuomašat dan álkit. Jus hálidat heaiti čuovvumis dan siiddu, deaddil liŋkka ''heaite čuovvumis'' siiddu ravddas.",
'removedwatchtext'     => "Siidu '''[[:$1]]''' lea sihkojuvvon du čuovvunlisttus.",
'watch'                => 'Čuovo',
'watchthispage'        => 'Čuovo dán siiddu',
'unwatch'              => 'Heaite čuovvumis',
'unwatchthispage'      => 'Heaite čuovvumis',
'notanarticle'         => 'Ii leat siidu',
'watchnochange'        => 'Válljejuvvon áigodagas oktage du čuovvunlisttui gullevaš siidu leat rievdaduvvon.',
'watchlist-details'    => 'Du čuovvunlisttus {{PLURAL:$1|lea $1 siidu|leat $1 siiddu}}. Lohkui eai leat váldojuvvon ságastallansiidduid.',
'wlheader-enotif'      => '* E-poastaalmmuhusat leat anus.',
'wlheader-showupdated' => "* Siiddut, mat leat rievdaduvvon du maŋimus geavahangearddi maŋŋá leat merkojuvvon '''buoiddes teavsttain'''",
'watchmethod-recent'   => 'dárkistuvvo varas rievdadusat čuovvunlisttu siidduide',
'watchmethod-list'     => 'dárkistuvvo čuovvunlisttu siidduid varas rievdadusat',
'watchlistcontains'    => 'Du čuovvunlisttus {{PLURAL:$1|lea okta siidu|leat $1 siiddu}}.',
'iteminvalidname'      => 'Siidduin $1 ledje váttisvuođat! Siiddu namas lea feaila.',
'wlnote'               => "Vuolábealde lea '''$1''' {{PLURAL:$1|rievdadus|rievdadusa}} maŋimus {{PLURAL:$2||'''$2'''}} diimma siste.",
'wlshowlast'           => 'Čájet maŋimus $1 diimmu dahje $2 beaivvi $3',

# Displayed when you click the "watch" button and it is in the process of watching
'watching'   => 'Lasihuvvo čuovvunlistui...',
'unwatching' => 'Sihkojuvvo čuovvunlisttus...',

'enotif_mailer'                => '{{GRAMMAR:genitive|{{SITENAME}}}} siidu lea rievdaduvvon -almmuhus',
'enotif_reset'                 => 'Merke buot siidduid gehččojuvvon',
'enotif_newpagetext'           => 'Dát lea ođđa siidu.',
'enotif_impersonal_salutation' => '{{SITENAME}}-geavaheaddji',
'changed'                      => 'rievdadan siiddu',
'created'                      => 'álggahan siiddu',
'enotif_subject'               => '$PAGEEDITOR on $CHANGEDORCREATED $PAGETITLE',
'enotif_lastvisited'           => 'Čujuhusas $1 leat buot rievdadusat du maŋimus geavahangearddi maŋŋá.',
'enotif_lastdiff'              => 'Rievdadus lea čujuhusas $1.',
'enotif_anon_editor'           => 'registereretkeahtes geavaheaddji $1',

# Delete
'deletepage'        => 'Sihko siiddu',
'confirm'           => 'Daga',
'excontent'         => 'sisdisdolii: ”$1”',
'exbeforeblank'     => 'sisdoallu ovdal gurrema: «$1»',
'exblank'           => 'lei guoros',
'historywarning'    => 'Siiddu, man aiggot sihkut, lea rievdaduvvon dávjit go oktii:',
'confirmdeletetext' => 'Leat sihkumin siiddu dahje fiilla ja buot dan historjjá. Ádde dagu váikkuhsaid ja sihko {{GRAMMAR:genitive|{{SITENAME}}}} [[{{MediaWiki:Policy-url}}|geavahaid]] mielde.',
'actioncomplete'    => 'Doaibma lea dahkkon',
'deletedtext'       => '"$1" lea sihkojuvvon.
Siiddus $2 lea listu maŋimus sihkomiin.',
'dellogpage'        => 'Sihkkunlogga',
'dellogpagetext'    => 'Vuolábealde lea logga maŋimus sihkkumiin.',
'deletionlog'       => 'sihkkunlogga',
'reverted'          => 'Máhcahuvvon ovddit veršuvdnii',
'deletecomment'     => 'Sivva',
'deleteotherreason' => 'Eará sivva:',

# Rollback
'rollback'         => 'máhcat ovddit veršuvdnii',
'rollback_short'   => 'Máhcaheapmi',
'rollbacklink'     => 'máhcat',
'rollbackfailed'   => 'Máhccan ii lihkosmuvvan',
'cantrollback'     => 'Máhcaheapmi ovddit veršuvdnii ii leat vejolaš, daningo maŋimuš čálli lea siiddu aidna dahkki.',
'alreadyrolled'    => 'Rievdadusat, maid geavaheaddji [[User:$2|$2]] ([[User talk:$2|ságastallan]]) lea dahkan, siidui $1 ii sáhte sihkkut, daningo geavaheaddji [[User:$3|$3]] ([[User talk:$3|ságastallan]]) lea dahkan ođđa rievdadusaid.',
'editcomment'      => "Rievdadusa čoahkkáigeassu lei: ''$1''.",
'revertpage'       => 'Geavaheaddji [[Special:Contributions/$2|$2]] ([[User_talk:$2|ságastallan]]) rievdadusat sihkkojuvvui ja siidu máhcahuvvui veršuvdnii, man geavaheaddji [[User:$1|$1]] lei dahkan.',
'rollback-success' => 'Rievdadusat, maid geavaheaddji ”$1” lei dahkan, sihkojuvvui ja artihkal máhcaduvvui veršuvdnii, man geavaheaddji $2 lei dahkan.',

# Protect
'protectlogpage'              => 'Suodjálanlogga',
'protectedarticle'            => 'suodjálii siiddu $1',
'modifiedarticleprotection'   => 'rievddai siiddu [[$1]] suodjálandási',
'unprotectedarticle'          => 'heittii siiddu $1 suodjaleami',
'protect-title'               => 'Siiddu $1 suodjáleapmi',
'prot_1movedto2'              => 'sirddii siiddu ”$1” ođđa namain ”$2”',
'protect-legend'              => 'Nanne suodjáleami',
'protectcomment'              => 'Sivva',
'protectexpiry'               => 'Boarásnuvvá',
'protect_expiry_invalid'      => 'Boarášnuvvánáigi ii dohket.',
'protect_expiry_old'          => 'Boarásnuvvánáigi lea vássán.',
'protect-default'             => 'Suova buot geavaheddjiid',
'protect-level-autoconfirmed' => 'Eastte anonyma ja ođđa geavaheddjiid',
'protect-level-sysop'         => 'Suova beare administráhtoriid',
'protect-summary-cascade'     => 'viiddiduvvon',
'protect-expiring'            => 'boarásnuvvá $1',
'protect-cascade'             => 'Viididt suodjálusa guoskat buot siidduit, mat gullet dán siidui',
'protect-othertime'           => 'Eará áigi:',
'protect-othertime-op'        => 'eará áigi',
'protect-dropdown'            => '** Dávjjes vandalisma
** Dávjjes spammen
** Rievdadansoahti
** Dehálaš siidu',
'protect-expiry-options'      => '2 diimma:2 hours,1 beaivi:1 day,3 beaivve:3 days,1 vahkku:1 week,2 vahkku:2 weeks,1 mánotbádji:1 month,3 mánotbaji:3 months,6 mánotbaji:6 months,1 jahki:1 year,bissovaš:infinite',
'restriction-type'            => 'Rádjehus',
'restriction-level'           => 'Suodjálus',
'minimum-size'                => 'Min. sturrodat',
'maximum-size'                => 'Maks. sturrodat:',
'pagesize'                    => 'stávvala',

# Restrictions (nouns)
'restriction-edit'   => 'rievdádeapmi',
'restriction-move'   => 'Sirdin',
'restriction-upload' => 'Fiilla vurken',

# Restriction levels
'restriction-level-sysop'         => 'ollislaččat suodjáluvvon',
'restriction-level-autoconfirmed' => 'oassái suodjáluvvon',
'restriction-level-all'           => 'mii beare suodjálus',

# Undelete
'undelete'                 => 'Bláđe sihkkojuvvon siidduid',
'undeletepage'             => 'Sihkojuvvon siidduid bláđen',
'viewdeletedpage'          => 'Sihkojuvvon siidduid bláđen',
'undeleterevisions'        => '{{PLURAL:$1|Okta veršuvdna|$1 veršuvnna}} lasihuvvon arkiivii.',
'undeletebtn'              => 'Máhcat',
'undeletereset'            => 'Gurre',
'undeletecomment'          => 'Kommeanta:',
'undeletedrevisions'       => '$1 veršuvnna máhcahuvvui',
'undeletedrevisions-files' => '$1 veršuvnna ja $2 fiilla máhcahuvvui',
'undeletedfiles'           => '$1 fii(l)la máhcahuvvui',
'cannotundelete'           => 'Máhcaheapmi ii lihkosmuvvan.',
'undelete-search-box'      => 'Oza sihkojuvvon siidduid',
'undelete-search-prefix'   => 'Čájet siidduid, mat álget mearkkaiguin:',
'undelete-search-submit'   => 'Oza',

# Namespace form on various pages
'namespace'      => 'Nammagomuvuohta',
'blanknamespace' => '(siiddut)',

# Contributions
'contributions'       => 'Geavaheaddji rievdadusat',
'contributions-title' => 'Geavaheaddji $1 rievdadusat',
'mycontris'           => 'Rievdadusat',
'uctop'               => '(ođđaseamos)',
'month'               => 'Mánotbadji',
'year'                => 'Jahki',

'sp-contributions-newbies'     => 'Čájet ođđa geavaheddjiid rievdadusaid',
'sp-contributions-newbies-sub' => 'Ođđa geavaheddjiid rievdadusat',
'sp-contributions-blocklog'    => 'cakkastallamat',
'sp-contributions-talk'        => 'ságastallan',
'sp-contributions-userrights'  => 'Geavaheaddjirivttiid stivren',
'sp-contributions-search'      => 'Oza rievdadusaid',
'sp-contributions-username'    => 'IP-čujuhus dahje geavaheaddjidovddaldat',
'sp-contributions-submit'      => 'Oza',

# What links here
'whatlinkshere'       => 'Siiddut mat čujuhit deike',
'whatlinkshere-title' => 'Siiddut mat čujuhit $1',
'linkshere'           => 'Čuovvovaš siidduin lea liŋka siidui <strong>[[:$1]]</strong>:',
'nolinkshere'         => 'Siidui <strong>[[:$1]]</strong> eai leat liŋkkat.',
'nolinkshere-ns'      => 'Siidui <strong>[[:$1]]</strong> eai leat liŋkkat válljejuvvon nammagomuvuođas.',
'isredirect'          => 'ođđasitstivrensiidu',
'istemplate'          => 'lasihuvvon mállevuođđui',
'whatlinkshere-prev'  => '← {{PLURAL:$1|ovddit siidu|$1 ovddit siiddu}}',
'whatlinkshere-next'  => '{{PLURAL:$1|čuovvovaš siidu|$1 čuovvovaš siiddu}} →',
'whatlinkshere-links' => 'liŋkkat',

# Block/unblock
'block'              => 'Hehtte geavaheaddji',
'blockip'            => 'Hehtte rievdadeamis',
'blockip-title'      => 'Cagge geavaheaddji',
'blockip-legend'     => 'Cagge geavaheaddji',
'ipadressorusername' => 'IP-čujuhus dahje geavaheaddjidovddaldat',
'ipbexpiry'          => 'Guhkkodat',
'ipbreason'          => 'Sivva',
'ipbreasonotherlist' => 'Eará sivva',
'ipbreason-dropdown' => '*Dábálas cakkastallansivat
** Boasto dieđuid lasiheapmi
** Sisdoalu sihkkun
** Reklámaliŋkkaid lasiheapmi
** Moiven dahje ruskkaid lasiheapmi
** Hehtten
** Maŋgga geavaheaddjidovddaldaga geaveaheapmi boastut
** Fasttes geavaheaddjidovddaldat',
'ipbcreateaccount'   => 'Eastte dovddaldagaid ráhkadeami',
'ipbemailban'        => 'Eastte geavaheaddji sáddemis e-poastta',
'ipbenableautoblock' => 'Eastte maŋimus IP-čujuhus, mas geavaheaddji lea ráhkadan rievdadusaid, ja maid daid čujuhusaid, main son vel iska rievdadit.',
'ipbsubmit'          => 'Hehtte dán geavaheaddji',
'ipbother'           => 'Eará áigi',
'ipboptions'         => '2 diimma:2 hours,1 beaivi:1 day,3 beaivve:3 days,1 vahkku:1 week,2 vahkku:2 weeks,1 mánotbádji:1 month,3 mánotbaji:3 months,6 mánotbaji:6 months,1 jahki:1 year,bissovaš:infinite',
'ipbotheroption'     => 'eará',
'ipbotherreason'     => 'Eará sivva',
'badipaddress'       => 'IP-čujuhus lea boastut.',
'blockipsuccesssub'  => 'Hehtten lihkosmuvai',
'blockipsuccesstext' => "Geavaheaddji dahje IP-čujuhus '''$1''' lea eston.<br />Dálá easttut gávdnot [[Special:BlockList|easttolisttus]].",
'ipb-edit-dropdown'  => 'Rievdat sivaid',
'ipb-unblock-addr'   => 'Sihko geavaheaddji $1 estema',
'ipb-unblock'        => 'Sihko geavaheaddji dahje IP-čujuhusa rievdadaneasttu',
'ipblocklist'        => 'Listu cakkojuvvon IP-adreassain ja geavaheddjiin',
'ipblocklist-submit' => 'Oza',
'infiniteblock'      => 'bissovaččat',
'expiringblock'      => 'boarásnuvvá $1 $2',
'blocklink'          => 'hehtte',
'contribslink'       => 'rievdadusat',
'blocklogentry'      => 'esttii geavaheaddji dahje IP-čujuhusa [[$1]], eastima bistin lea $2 $3',
'proxyblocksuccess'  => 'Gárvvis.',

# Developer tools
'lockdb'             => 'Gidde diehtovuođu',
'unlockdb'           => 'Raba diehtovuođu',
'lockconfirm'        => 'Jua, háliidan sihkkarit giddet diehtovuođu.',
'unlockconfirm'      => 'Jua, háliidan sihkkarit rahpat diehtovuođu.',
'lockbtn'            => 'Gidde diehtovuođu',
'unlockbtn'          => 'Raba diehtovuođu',
'lockdbsuccesssub'   => 'Diehtovuođu gidden lihkosmuvai',
'unlockdbsuccesssub' => 'Diehtovuođu rahpan lihkosmuvai',

# Move page
'move-page-legend'        => 'Sirdde siiddu',
'movearticle'             => 'Sirdde siiddu',
'movenologin'             => 'It leat čálligoahtán sisa',
'newtitle'                => 'Ođđa namma siidui',
'move-watch'              => 'Čuovo dán siiddu',
'movepagebtn'             => 'Sirdde siiddu',
'pagemovedsub'            => 'Sirdin lihkosmuvai',
'talkexists'              => "'''Siiddu sirdin iešalddes lihkosmuvai, earret siiddu ságastallansiiddu sirdin daningo ođđa bájilčálas lea jo ságastallansiidu. Leage buorre ja sirdde ságastallamiid manuálalažžat.'''",
'movedto'                 => 'Sirdojuvvun ođđa bájilčállagin',
'movetalk'                => 'Sirdde maid ságastallansiiddu.',
'movelogpage'             => 'Sirdinlogga',
'movelogpagetext'         => 'Dát lea logga sirdojuvvon siidduin.',
'movereason'              => 'Sivva',
'revertmove'              => 'šluhtte',
'delete_and_move'         => 'Sihko siiddu ja sirdde',
'delete_and_move_confirm' => 'Sihko siiddu',

# Export
'export'          => 'Olggosfievrrit siidduid',
'export-addcat'   => 'Lasit',
'export-download' => 'Vurke fiillan',

# Namespace 8 related
'allmessages'        => 'Buot systemasánit',
'allmessagesname'    => 'Namma',
'allmessagescurrent' => 'Dálá teaksta',

# Thumbnails
'thumbnail-more' => 'Stuorit',
'filemissing'    => 'Fiila váilo',

# Special:Import
'import-comment'        => 'Sivva',
'import-revision-count' => '$1 {{PLURAL:$1|veršuvdna|veršuvnnat}}',

# Import log
'import-logentry-upload-detail' => '$1 veršuvdna/veršuvnna',

# Tooltip help for the actions
'tooltip-pt-userpage'             => 'Iežas geavaheaddjisiidu',
'tooltip-pt-anonuserpage'         => 'Du IP-čujuhusat geavaheaddjisiidu',
'tooltip-pt-mytalk'               => 'Iežas ságastallansiidu',
'tooltip-pt-anontalk'             => 'Ságastallan rievdadusain, maid dát IP-čujuhus lea ráhkadan',
'tooltip-pt-preferences'          => 'Iežas ásahusat',
'tooltip-pt-watchlist'            => 'Listu siidduin, maid rievdadusaid don čuovut',
'tooltip-pt-mycontris'            => 'Listu iežas rievdadusain',
'tooltip-pt-login'                => 'Čálligoađe sisa dahje ráhkat geavaheaddjidovddaldaga',
'tooltip-pt-anonlogin'            => 'Čálligoađe sisa dahje ráhkat geavaheaddjidovddaldaga',
'tooltip-pt-logout'               => 'Logge olggos',
'tooltip-ca-talk'                 => 'Ságastala sisdoalus',
'tooltip-ca-edit'                 => 'Rievdat dán siiddu',
'tooltip-ca-addsection'           => 'Lasit kommeantta dán siidui',
'tooltip-ca-viewsource'           => 'Čájet siiddu gáldokoda',
'tooltip-ca-history'              => 'Siiddu ovddit veršuvnnat',
'tooltip-ca-protect'              => 'Suodjal dán siiddu',
'tooltip-ca-delete'               => 'Sihko dán siiddu',
'tooltip-ca-undelete'             => 'Máhcat dán siiddu',
'tooltip-ca-move'                 => 'Sirdde dán siiddu',
'tooltip-ca-watch'                => 'Lasit dán siiddu iežat čuovvunlistui',
'tooltip-ca-unwatch'              => 'Sirdde dán siiddu eret du čuovvunlisttus',
'tooltip-search'                  => 'Oza {{SITENAME}}s',
'tooltip-p-logo'                  => 'Váldosiidu',
'tooltip-n-mainpage'              => 'Mana váldosiidui',
'tooltip-n-portal'                => 'Ságastallan prošeavttas',
'tooltip-n-currentevents'         => 'Dieđut Wikipedia áigeguovdilis dáhpáhusain',
'tooltip-n-recentchanges'         => 'Listu varas rievdadusain',
'tooltip-n-randompage'            => 'Raba summal siidu',
'tooltip-n-help'                  => 'Rávvagat',
'tooltip-t-whatlinkshere'         => 'Listu siiddui, mat čujuhit deike',
'tooltip-t-recentchangeslinked'   => 'Varas rievdadusat siiddui, maidda čujuhuvvo dán siiddus',
'tooltip-t-contributions'         => 'Čájet listtu dán geavaheaddji rievdadusain',
'tooltip-t-emailuser'             => 'Sádde e-poastta dán geavaheaddjái',
'tooltip-t-upload'                => 'Vurke govaid dahje eará mediafiillaid',
'tooltip-t-specialpages'          => 'Čájet doaibmasiidduid',
'tooltip-t-print'                 => 'Prentenveršuvdna',
'tooltip-t-permalink'             => 'Bissovaš liŋka dán veršuvdnii',
'tooltip-ca-nstab-main'           => 'Čájet sisdoallosiiddu',
'tooltip-ca-nstab-user'           => 'Čájet geavaheaddjisiiddu',
'tooltip-ca-nstab-media'          => 'Čájet mediasiiddu',
'tooltip-ca-nstab-special'        => 'Dát lea doaibmasiidu',
'tooltip-ca-nstab-project'        => 'Čájet prošeaktasiiddu',
'tooltip-ca-nstab-image'          => 'Čájet diehtosiiddu',
'tooltip-ca-nstab-mediawiki'      => 'Čájet vuogádatdieđáhusa',
'tooltip-ca-nstab-template'       => 'Čájet mállevuođu',
'tooltip-ca-nstab-help'           => 'Čájet ravvagiid',
'tooltip-ca-nstab-category'       => 'Čájet luohkkásiiddu',
'tooltip-minoredit'               => 'Merkke dán rievdadusa unna rievadussan',
'tooltip-save'                    => 'Vurke rievdadusaid',
'tooltip-preview'                 => 'Geahča rievdadusa ovdalgihtii ovdal vurkema',
'tooltip-diff'                    => 'Čájet rievdadusaid',
'tooltip-compareselectedversions' => 'Veardit válljejuvvon veršuvnnaid.',
'tooltip-watch'                   => 'Lasit dán siiddu čuovvunlisttui',
'tooltip-recreate'                => 'Álggat dán siiddu ođđasit',

# Attribution
'anonymous'   => '{{SITENAME}}-siiddu anonyma {{PLURAL:$1|geavaheaddji|geavaheaddjit}}',
'siteuser'    => '{{GRAMMAR:genitive|{{SITENAME}}}} geavaheaddji $1',
'others'      => 'earát',
'siteusers'   => '{{GRAMMAR:genitive|{{SITENAME}}}} geavaheaddji(t) $1',
'creditspage' => 'Siiddu dahkkit',

# Patrolling
'markaspatrolleddiff'   => 'Merke dárkistuvvon',
'markaspatrolledtext'   => 'Merke, ahte rievdadus lea dárkistuvvon',
'markedaspatrolled'     => 'Dárkistuvvon',
'markedaspatrolledtext' => 'Válljejuvvon veršuvdna lea dárkistuvvon.',

# Browsing diffs
'previousdiff' => '← Ovddit rievdadus',
'nextdiff'     => 'Čuovvovaš rievdadus →',

# Media information
'thumbsize'       => 'Thumbnail sturrodat:',
'widthheightpage' => '$1 × $2, $3 siiddut',

# Special:NewFiles
'newimages'             => 'Ođđa govat',
'imagelisttext'         => "Vuolábealde lea '''$1''' fiilla ordnejuvvon $2.",
'noimages'              => 'Ii oaidnámus.',
'ilsubmit'              => 'Oza',
'bydate'                => 'beaivemeari mielde',
'sp-newimages-showfrom' => 'Čájet ođđa govaid $1 rájes',

# Metadata
'metadata-expand'   => 'Čájet buot sisdoallogovvádusaid',
'metadata-collapse' => 'Čájet beare dehaleamos sisdoallogovvádusaid',

# EXIF tags
'exif-imagewidth'         => 'Viidodat',
'exif-imagelength'        => 'Allodat',
'exif-bitspersample'      => 'Bihtá komponeanttas',
'exif-orientation'        => 'Guovlu',
'exif-imagedescription'   => 'Gova namma',
'exif-usercomment'        => 'Geavaheaddji kommeanttat',
'exif-gpsareainformation' => 'GPS-guovllu namma',
'exif-gpsdatestamp'       => 'GPS-beaivemearri',

'exif-unknowndate' => 'Dovdameahttun beaivemearri',

'exif-orientation-1' => 'Normála',

'exif-componentsconfiguration-0' => 'ii leat',

'exif-exposureprogram-0' => 'Ii meroštallojuvvon',
'exif-exposureprogram-2' => 'Vuođđoprográmma',

'exif-subjectdistance-value' => '$1 mehtera',

'exif-meteringmode-0'   => 'Dovdameahttun',
'exif-meteringmode-1'   => 'Gaskaárvu',
'exif-meteringmode-3'   => 'Čuoggis',
'exif-meteringmode-255' => 'Eará',

'exif-lightsource-0'  => 'Dovdameahttun',
'exif-lightsource-1'  => 'Beaivečuovga',
'exif-lightsource-4'  => 'Álddagas',
'exif-lightsource-10' => 'Obbadálki',

'exif-scenecapturetype-0' => 'Vuođđo',
'exif-scenecapturetype-3' => 'Idjagovva',

'exif-gaincontrol-0' => 'Ii leat',

'exif-contrast-0' => 'Normála',
'exif-contrast-2' => 'Garra',

'exif-saturation-0' => 'Normála',

'exif-sharpness-0' => 'Normála',
'exif-sharpness-2' => 'Garra',

'exif-subjectdistancerange-0' => 'Dovdameahttun',

# Pseudotags used for GPSSpeedRef
'exif-gpsspeed-k' => 'km/h',
'exif-gpsspeed-m' => 'miilla diimmus',
'exif-gpsspeed-n' => 'čuolmma',

# 'all' in various places, this might be different for inflected languages
'watchlistall2' => ', olles historjjá',
'namespacesall' => 'buot',
'monthsall'     => 'buot',

# Email address confirmation
'confirmemail'          => 'Sihkaraste e-poastačujuhusa',
'confirmemail_noemail'  => 'Dus ii leat lasihuvvon gelbbolaš e-poastačujuhus [[Special:Preferences|ásahusain]].',
'confirmemail_success'  => 'Du e-poastačujuhus lea dál konfirmerejuvvon. Sáhtát dál logget sisa.',
'confirmemail_loggedin' => 'Du e-poastačujuhus lea dál konfirmerejuvvon.',
'confirmemail_subject'  => '{{GRAMMAR:genitive|{{SITENAME}}}} e-poastačujuhusa konfirmeren',

# Scary transclusion
'scarytranscludetoolong' => '[Čujuhus lea menddo guhkki]',

# Delete conflict
'deletedwhileediting' => "'''Cuiggodus''': Dát siidu lea sihkkojuvvon das maŋŋá go leat álggahan ođasmahttit dan!",
'recreate'            => 'Álggat ođđasit',

# action=purge
'confirm_purge_button' => 'Sihko',

# Multipage image navigation
'imgmultipageprev' => '← ovddit siidu',
'imgmultipagenext' => 'čuovvovaš siidu →',
'imgmultigo'       => 'Mana!',

# Table pager
'ascending_abbrev'         => 'loktaneaddji',
'descending_abbrev'        => 'vuolláneaddji',
'table_pager_next'         => 'Čuovvovaš siidu',
'table_pager_prev'         => 'Ovddit siidu',
'table_pager_first'        => 'Vuosttas siidu',
'table_pager_last'         => 'Maŋimus siidu',
'table_pager_limit_submit' => 'Mana',
'table_pager_empty'        => 'Eai bohtosat',

# Auto-summaries
'autoredircomment' => 'Ođđasitstivrejuvvo [[$1]]-siidui',
'autosumm-new'     => 'Ođđa siidu: $1',

# Size units
'size-kilobytes' => '$1 KiB',
'size-megabytes' => '$1 MiB',
'size-gigabytes' => '$1 GiB',

# Watchlist editor
'watchlistedit-noitems'      => 'Du čuovvunlistu lea guoros',
'watchlistedit-normal-title' => 'Čuovvunlisttu ođasmahttin',
'watchlistedit-raw-titles'   => 'Siiddut',
'watchlistedit-raw-submit'   => 'Beaivit čuovvunlisttu',
'watchlistedit-raw-done'     => 'Du čuovvunlistu lea beaiváduvvon.',
'watchlistedit-raw-added'    => '{{PLURAL:$1|Okta siidu|$1 siiddu}} lasihuvvui:',
'watchlistedit-raw-removed'  => '{{PLURAL:$1|Okta siidu|$1 siiddu}} sihkkojuvvui:',

# Watchlist editing tools
'watchlisttools-view' => 'Čájet rievdadusaid',
'watchlisttools-edit' => 'Ođasmahte listtu',

# Special:Version
'version' => 'Veršuvdna',

# Special:SpecialPages
'specialpages' => 'Erenomáš siiddut',

# New logging system
'logentry-delete-delete'              => '$1 sihkui siiddu $3',
'logentry-delete-restore'             => '$1 máhcahii siiddu $3',
'logentry-move-move'                  => '$1 sirddii siiddu $3 nammii $4',
'logentry-move-move_redir-noredirect' => '$1 sirddii siiddu $3 nammii $4 iige ráhkadan ođđasitstivrema',
'logentry-newusers-create'            => '$1 ráhkadii dovddaldaga',
'logentry-newusers-autocreate'        => 'Dovddaldat $1 ráhkaduvvui automáhtalaččat',

);
